Functions
:::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   Floating-point.rst
   ConvertingFromDoubleToInt.rst
   MathFunctions.rst
   Composition.rst
   AddingNewFunctions.rst
   DefinitionsAndUses.rst
   ProgramsWithMultipleFunctions.rst
   ParametersAndArguments.rst
   ParametersAndVariablesAreLocal.rst
   FunctionsWithMultipleParameters.rst
   FunctionsWithResults.rst
   Glossary.rst 
   Exercises.rst
   mixedUpCode.rst
   activeCode.rst
